# `exports:delete`

```sh
rai exports:delete [OPTIONS]
```

Delete a SQL object, such as a stored procedure, that has been exported from RelationalAI to Snowflake.

## Options

| Option | Type | Required | Description |
| :--- | :--- | :--- | :------ |
| `--export` | String | Yes | The [fully-qualified name](https://docs.snowflake.com/en/sql-reference/name-resolution) of the exported Snowflake object. |
| `--model` | String | Yes | The name of the [model](../python/Model/README.md) from which the export originates. |

## Example

Delete the stored procedure named `my_export` generated by the RelationalAI model `myModel`:

```sh
rai exports:delete --export my_database.my_schema.my_export --model myModel
```
